Documentation
¶
Overview ¶
Package keeper provides methods to initialize SDK keepers with local storage for test purposes
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FeeMarket ¶
func FeeMarket( initializer *testkeeper.Initializer, authKeeper authkeeper.AccountKeeper, ) *feemarketkeeper.Keeper
FeeMarket initializes the fee market module using the testkeepers intializer.
func NewTestSetup ¶
func NewTestSetup(t testing.TB, options ...testkeeper.SetupOption) (sdk.Context, TestKeepers, TestMsgServers)
NewTestSetup returns initialized instances of all the keepers and message servers of the modules
Types ¶
type TestKeepers ¶
type TestKeepers struct {
testkeeper.TestKeepers
FeeMarketKeeper *feemarketkeeper.Keeper
}
TestKeepers holds all keepers used during keeper tests for all modules
type TestMsgServers ¶
type TestMsgServers struct {
testkeeper.TestMsgServers
FeeMarketMsgServer feemarkettypes.MsgServer
}
TestMsgServers holds all message servers used during keeper tests for all modules
Click to show internal directories.
Click to hide internal directories.